pub fn run(schema_path: &str) -> Result<CommandResult>Expand description
Run analyze command
Errors
Returns an error if the schema file cannot be read or cannot be parsed as JSON.
pub fn run(schema_path: &str) -> Result<CommandResult>Run analyze command
Returns an error if the schema file cannot be read or cannot be parsed as JSON.