run

Function run 

pub fn run(schema_path: &str, format: GraphFormat) -> Result<CommandResult>
Run the dependency graph command

Errors

Returns an error if the schema file cannot be read or cannot be deserialized as a CompiledSchema. Also propagates JSON serialization errors for the selected output format.