pub fn run(query: &str) -> Result<CommandResult>Expand description
Run explain command
Errors
Returns an error if the query cannot be parsed or if complexity analysis fails. Also propagates errors from JSON serialization of the response.
pub fn run(query: &str) -> Result<CommandResult>Run explain command
Returns an error if the query cannot be parsed or if complexity analysis fails. Also propagates errors from JSON serialization of the response.