run

Function run 

pub fn run(input: &str, language: Language, output: Option<&str>) -> Result<()>
Run the generate command.

Errors

Returns an error if the input schema file cannot be read or parsed as IntermediateSchema, or if the generated output file cannot be written.