run

Function run 

pub fn run(schema_path: &str, opts: LintOptions) -> Result<CommandResult>
Run lint command on a schema

Errors

Returns an error if the schema file does not exist, cannot be read, cannot be parsed as JSON, or if design audit initialization fails.