run

Function run 

pub async fn run(schema: &str, port: u16) -> Result<()>
Run the serve command (development server with hot-reload)

Arguments

  • schema - Path to schema.json file to watch
  • port - Port to listen on (for future GraphQL server integration)

Behavior

  1. Compiles the initial schema
  2. Watches schema.json for file changes
  3. Auto-recompiles on save
  4. Provides compilation feedback

Errors

Returns an error if the schema file does not exist, if the file watcher cannot be created or started, or if the watch channel closes unexpectedly.

Future Enhancement

Will integrate with fraiseql-server to provide hot-reload of the GraphQL endpoint