Module setup

Module setup 

fraiseql setup - Install FraiseQL helpers to a PostgreSQL database.

Installs SQL helper functions (fraiseql.mutation_ok, fraiseql.mutation_err, etc.) to the target database. These helpers reduce boilerplate when writing mutation functions under the v2.2.0 protocol.

Functions

run
Run the setup command to install helpers to a database.