create_introspector

Function create_introspector 

pub async fn create_introspector(db_url: &str) -> Result<AnyIntrospector>
Create an introspector from a database URL.

Detects the database type from the URL scheme and creates the appropriate introspector with a connection pool.

Errors

Returns error if the URL scheme is unrecognized or the connection pool cannot be created.