pub fn run(config: &InitConfig) -> Result<()>Expand description
Run the init command
Errors
Returns an error if the target directory already exists, if any file or directory creation fails, or if the language skeleton cannot be written.
pub fn run(config: &InitConfig) -> Result<()>Run the init command
Returns an error if the target directory already exists, if any file or directory creation fails, or if the language skeleton cannot be written.