fraiseql migrate - Database migration wrapper
Wraps confiture for database migrations, providing a unified CLI experience without requiring users to install confiture separately.
Enums
- Migrate
Action - Migration subcommand
Functions
- resolve_
database_ url - Resolve the database URL: use explicit flag, or fall back to fraiseql.toml
- resolve_
migration_ dir - Resolve the migration directory: use explicit flag, or auto-discover
- run
- Run the migrate command